==> lxqt-panel-0.9.0.tar.xz: lxqt-panel-0.9.0/plugin-mainmenu/translations/mainmenu_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LxQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="314"/>
        <source>Show/hide main menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="339"/>
        <source>Leave</source>
        <translation>Išeiti</translation>
    </message>
</context>
<context>
    <name>LxQtMainMenuConfiguration</name>
    <message>
        <source>LxQt Main Menu settings</source>
        <translation type="vanished">LxQt pagrindinio meniu nuostatos</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Pagrindinės</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation type="vanished">Rodyti tekstą</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation type="vanished">Mygtuko tekstas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Button text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="52"/>
        <source>Custom font size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="62"/>
        <source> pt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="81"/>
        <source>Menu file</source>
        <translation>Meniu rinkmena</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="87"/>
        <source>Menu file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="101"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Keyboard Shortcut</source>
        <translation>Spartusis klavišas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="130"/>
        <source>Click the button to record shortcut:</source>
        <translation>Norėdami pakeisti klavišą, spragtelėkite</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="55"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="100"/>
        <source>Choose menu file</source>
        <translation>Pasirinkite meniu failą</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="100"/>
        <source>Menu files (*.menu)</source>
        <translation>Meniu failai (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-panel-0.10.0.tar.xz: lxqt-panel-0.10.0/plugin-mainmenu/translations/mainmenu_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="245"/>
        <source>Show/hide main menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leave</source>
        <translation type="vanished">Išeiti</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <source>LXQt Main Menu settings</source>
        <translation type="vanished">LXQt pagrindinio meniu nuostatos</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Pagrindinės</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation type="vanished">Rodyti tekstą</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation type="vanished">Mygtuko tekstas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Button text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="52"/>
        <source>Custom font size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="62"/>
        <source> pt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="81"/>
        <source>Menu file</source>
        <translation>Meniu rinkmena</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="87"/>
        <source>Menu file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="101"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Keyboard Shortcut</source>
        <translation>Spartusis klavišas</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="130"/>
        <source>Click the button to record shortcut:</source>
        <translation>Norėdami pakeisti klavišą, spragtelėkite</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="55"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="100"/>
        <source>Choose menu file</source>
        <translation>Pasirinkite meniu failą</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="100"/>
        <source>Menu files (*.menu)</source>
        <translation>Meniu failai (*.menu)</translation>
    </message>
</context>
</TS>
